@@ -1,22 +1,20 @@
-import pytest
-
 import numpy as np
+import pytest
 from scipy import sparse
-
+from sklearn.cluster import KMeans
 from sklearn.datasets import load_iris
 
 keras = pytest.importorskip("keras")
-from keras.models import Sequential  # noqa: E402
 from keras.layers import Dense  # noqa: E402
+from keras.models import Sequential  # noqa: E402
 from keras.utils.np_utils import to_categorical  # noqa: E402
 
 from imblearn.datasets import make_imbalance  # noqa: E402
-from imblearn.under_sampling import ClusterCentroids  # noqa: E402
-from imblearn.under_sampling import NearMiss  # noqa: E402
-from imblearn.over_sampling import RandomOverSampler  # noqa: E402
-
 from imblearn.keras import BalancedBatchGenerator  # noqa: E402
 from imblearn.keras import balanced_batch_generator  # noqa: E402
+from imblearn.over_sampling import RandomOverSampler  # noqa: E402
+from imblearn.under_sampling import ClusterCentroids  # noqa: E402
+from imblearn.under_sampling import NearMiss  # noqa: E402
 
 
 @pytest.fixture
@@ -40,7 +38,9 @@ def _build_keras_model(n_classes, n_features):
 
 def test_balanced_batch_generator_class_no_return_indices(data):
     with pytest.raises(ValueError, match="needs to have an attribute"):
-        BalancedBatchGenerator(*data, sampler=ClusterCentroids(), batch_size=10)
+        BalancedBatchGenerator(
+            *data, sampler=ClusterCentroids(estimator=KMeans(n_init=1)), batch_size=10
+        )
 
 
 @pytest.mark.filterwarnings("ignore:`wait_time` is not used")  # keras 2.2.4
@@ -88,7 +88,10 @@ def test_balanced_batch_generator_class_sparse(data, keep_sparse):
 def test_balanced_batch_generator_function_no_return_indices(data):
     with pytest.raises(ValueError, match="needs to have an attribute"):
         balanced_batch_generator(
-            *data, sampler=ClusterCentroids(), batch_size=10, random_state=42
+            *data,
+            sampler=ClusterCentroids(estimator=KMeans(n_init=10)),
+            batch_size=10,
+            random_state=42,
         )
 
 
