@@ -11,4 +11,4 @@ from imblearn.exceptions import raise_isinstance_error
 def test_raise_isinstance_error():
     var = 10.0
     with raises(ValueError, match="has to be one of"):
-        raise_isinstance_error('var', [int], var)
+        raise_isinstance_error("var", [int], var)
